pub trait TimeConvexIterator: Iterator<Item = TimeInterval<Self::TimePoint>> + Sized {
type TimePoint: TimePoint;
}Expand description
An iterator over sorted and distinct time intervals
This trait specifies the type of the base temporal data (date or duration) and ensures that it exists an iterator over convex parts (time intervals) of the time window.
By contract, this iterator should produce its time intervals in a sorted manner. It means also that no time intervals overlap
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".